about summary refs log tree commit diff
path: root/nixpkgs/pkgs/development/libraries/x264/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'nixpkgs/pkgs/development/libraries/x264/default.nix')
-rw-r--r--nixpkgs/pkgs/development/libraries/x264/default.nix25
1 files changed, 13 insertions, 12 deletions
diff --git a/nixpkgs/pkgs/development/libraries/x264/default.nix b/nixpkgs/pkgs/development/libraries/x264/default.nix
index 276f509772c2..9998add0d930 100644
--- a/nixpkgs/pkgs/development/libraries/x264/default.nix
+++ b/nixpkgs/pkgs/development/libraries/x264/default.nix
@@ -1,36 +1,37 @@
-{stdenv, fetchurl, yasm, enable10bit ? false}:
+{ stdenv, fetchurl, nasm }:
 
 stdenv.mkDerivation rec {
-  version = "20170731-2245";
-  name = "x264-${version}";
+  pname = "x264";
+  version = "20190517-2245";
 
   src = fetchurl {
     url = "https://download.videolan.org/x264/snapshots/x264-snapshot-${version}-stable.tar.bz2";
-    sha256 = "01sgk1ps4qfifdnblwa3fxnd8ah6n6zbmfc1sy09cgqcdgzxgj0z";
+    sha256 = "1xv41z04km3rf374xk3ny7v8ibr211ph0j5am0909ln63mphc48f";
   };
 
-  patchPhase = ''
-    sed -i s,/bin/bash,${stdenv.shell}, configure version.sh
+  postPatch = ''
+    patchShebangs .
   '';
 
-  outputs = [ "out" "lib" ]; # leaving 52 kB of headers
+  enableParallelBuilding = true;
+
+  outputs = [ "out" "lib" "dev" ];
 
   preConfigure = ''
     # `AS' is set to the binutils assembler, but we need yasm
     unset AS
   '';
 
   configureFlags = [ "--enable-shared" ]
-    ++ stdenv.lib.optional (!stdenv.isi686) "--enable-pic"
-    ++ stdenv.lib.optional (enable10bit) "--bit-depth=10";
+    ++ stdenv.lib.optional (!stdenv.isi686) "--enable-pic";
 
-  buildInputs = [ yasm ];
+  nativeBuildInputs = [ nasm ];
 
   meta = with stdenv.lib; {
     description = "Library for encoding H264/AVC video streams";
     homepage    = http://www.videolan.org/developers/x264.html;
     license     = licenses.gpl2;
     platforms   = platforms.unix;
-    maintainers = [ maintainers.spwhitt ];
+    maintainers = with maintainers; [ spwhitt tadeokondrak ];
   };
 }
@@ -1,36 +1,37 @@
 
   preConfigure = ''
-    # `AS' is set to the binutils assembler, but we need yasm
+    # `AS' is set to the binutils assembler, but we need nasm
     unset AS
   '';